<?php
require_once 'db.php';

function getUserEnergyInfo($userId) {
    global $conn;
    $stmt = $conn->prepare("SELECT energy_level FROM user_boosts WHERE user_id = ?");
    $stmt->bind_param("s", $userId);

    if ($stmt->execute()) {
        $result = $stmt->get_result();
        if ($row = $result->fetch_assoc()) {
            return $row['energy_level'];
        } else {
            return null;
        }
    } else {
        echo "Error executing query: " . $stmt->error;
        return false;
    }

    $stmt->close();
}

function calculateNextEnergyPurchasePrice($currentLevel) {
    $basePrice = 1000;
    $increment = 1000;
    return $basePrice + ($currentLevel * $increment);
}

function calculateEnergyReward($currentLevel) {
    $baseReward = 1000;
    $increment = 1000;
    return $baseReward + ($currentLevel * $increment);
}

$data = json_decode(file_get_contents('php://input'), true);
if (isset($data['user_id'])) {
    $userId = $data['user_id'];
    $EnergyLevel = getUserEnergyInfo($userId);

    if ($EnergyLevel !== null) {
        $nextPurchasePrice = calculateNextEnergyPurchasePrice($EnergyLevel);
        $reward = calculateEnergyReward($EnergyLevel);

        echo json_encode([
            'energy_boost_level' => $EnergyLevel,
            'next_energy_purchase_price' => $nextPurchasePrice,
            'energy_capacity' => $reward
        ]);
    } else {
        http_response_code(404);
        echo json_encode(['error' => 'User not found or no energy_level set']);
    }
} else {
    http_response_code(400);
    echo json_encode(['error' => 'User ID is required']);
}

$conn->close();
?>
