<?php
require_once 'db.php';

function getUserBalance($userId) {
    global $conn;
    $stmt = $conn->prepare("SELECT SUM(amount) as balance FROM transactions WHERE userid = ?");
    $stmt->bind_param("s", $userId);

    if ($stmt->execute()) {
        $result = $stmt->get_result();
        if ($row = $result->fetch_assoc()) {
            return $row['balance'] ?? 0;
        }
    }
    return 0;
}

function updateUserSuperTapLevel($userId, $newLevel) {
    global $conn;
    $stmt = $conn->prepare("UPDATE user_boosts SET supertap_level = ? WHERE user_id = ?");
    $stmt->bind_param("is", $newLevel, $userId);

    return $stmt->execute();
}

function addNewTransaction($userId, $amount, $description) {
    global $conn;
    $transId = uniqid('trans_', true);
    $transDate = date('Y-m-d H:i:s');
    $type = 'debit';

    $stmt = $conn->prepare("INSERT INTO transactions (trans_id, trans_date, amount, type, description, userid) VALUES (?, ?, ?, ?, ?, ?)");
    $stmt->bind_param("ssdsss", $transId, $transDate, $amount, $type, $description, $userId);

    return $stmt->execute();
}


function calculateNextSuperTapPurchasePrice($currentLevel) {
    // Example calculation: Base price + (level * increment)
    $basePrice = 10000; // Base price for the next purchase
    $increment = 10000; // Incremental cost per level
    return $basePrice + ($currentLevel * $increment);
}
$data = json_decode(file_get_contents('php://input'), true);

if (isset($data['user_id'])) {
    $userId = $data['user_id'];
    $stmt = $conn->prepare("SELECT supertap_level FROM user_boosts WHERE user_id = ?");
    $stmt->bind_param("s", $userId);

    if ($stmt->execute()) {
        $result = $stmt->get_result();
        if ($row = $result->fetch_assoc()) {
            $currentLevel = $row['supertap_level'];
            $nextPurchasePrice = calculateNextSuperTapPurchasePrice($currentLevel);

            $balance = getUserBalance($userId);

            if ($balance >= $nextPurchasePrice) {
                if (addNewTransaction($userId, -$nextPurchasePrice, "Purchase supertap level " . ($currentLevel + 1))) {
                    if (updateUserSuperTapLevel($userId, $currentLevel + 1)) {
                        echo json_encode(['message' => 'SuperTap level purchased successfully']);
                    } else {
                        http_response_code(500);
                        echo json_encode(['error' => 'Unable to update supertap level']);
                    }
                } else {
                    http_response_code(500);
                    echo json_encode(['error' => 'Unable to add transaction']);
                }
            } else {
                http_response_code(400);
                echo json_encode(['error' => 'Insufficient balance']);
            }
        } else {
            http_response_code(404);
            echo json_encode(['error' => 'User not found']);
        }
    } else {
        http_response_code(500);
        echo json_encode(['error' => 'Error executing query: ' . $stmt->error]);
    }

    $stmt->close();
} else {
    http_response_code(400);
    echo json_encode(['error' => 'User ID is required']);
}

$conn->close();
?>
