<?php
require_once 'db.php';

function getInviteCount($userId) {
    global $conn;
    $stmt = $conn->prepare("SELECT COUNT(*) as invite_count FROM invitations WHERE inviter_id = ?");
    $stmt->bind_param("s", $userId);
    
    if ($stmt->execute()) {
        $result = $stmt->get_result();
        if ($row = $result->fetch_assoc()) {
            return $row['invite_count'];
        }
    }
    return 0;
}

function getNextInviteReward($inviteCount) {
    // return 10000;
    global $conn;
    $stmt = $conn->prepare("SELECT threshold, reward FROM invite_rewards WHERE threshold <= ? ORDER BY threshold DESC LIMIT 1");
    $stmt->bind_param("i", $inviteCount);

    if ($stmt->execute()) {
        $result = $stmt->get_result();
        if ($row = $result->fetch_assoc()) {
            return $row;
        }
    }
    return null;
}

function hasClaimedInviteReward($userId, $threshold) {
    global $conn;
    $stmt = $conn->prepare("SELECT 1 FROM is_claimed_invite WHERE userid = ? AND threshold = ?");
    $stmt->bind_param("si", $userId, $threshold);

    if ($stmt->execute()) {
        return $stmt->get_result()->num_rows > 0;
    }
    return false;
}

function claimInviteReward($userId, $threshold) {
    global $conn;
    $stmt = $conn->prepare("INSERT INTO is_claimed_invite (userid, threshold) VALUES (?, ?)");
    $stmt->bind_param("si", $userId, $threshold);

    return $stmt->execute();
}

function addNewTransaction($userId, $amount, $description) {
    global $conn;
    $transId = uniqid('trans_', true);
    $transDate = date('Y-m-d H:i:s');
    $type = 'credit';

    $stmt = $conn->prepare("INSERT INTO transactions (trans_id, trans_date, amount, type, description, userid) VALUES (?, ?, ?, ?, ?, ?)");
    $stmt->bind_param("ssdsss", $transId, $transDate, $amount, $type, $description, $userId);

    return $stmt->execute();
}

$data = json_decode(file_get_contents('php://input'), true);

if (isset($data['user_id'])) {
    $userId = $data['user_id'];
    $inviteCount = getInviteCount($userId);
    $rewardInfo = getNextInviteReward($inviteCount);

    if ($rewardInfo && !hasClaimedInviteReward($userId, $rewardInfo['threshold'])) {
        if (claimInviteReward($userId, $rewardInfo['threshold'])) {
            if (addNewTransaction($userId, $rewardInfo['reward'], "Invite reward claimed for threshold {$rewardInfo['threshold']}")) {
                echo json_encode(['message' => 'Reward claimed successfully', 'reward' => $rewardInfo['reward']]);
            } else {
                http_response_code(500);
                echo json_encode(['error' => 'Unable to add transaction']);
            }
        } else {
            http_response_code(500);
            echo json_encode(['error' => 'Unable to claim reward']);
        }
    } else {
        http_response_code(400);
        echo json_encode(['error' => 'No eligible reward to claim or already claimed']);
    }
} else {
    http_response_code(400);
    echo json_encode(['error' => 'User ID is required']);
}

$conn->close();
?>
