<?php
require_once 'db.php';

$data = json_decode(file_get_contents('php://input'), true);

if (isset($data['user_id']) && isset($data['invited_id'])) {
    $inviter_id = htmlspecialchars($data['user_id']);
    $invited_id = htmlspecialchars($data['invited_id']);
    $amount=10000;
    $description="Invitation reward";
    try {
        // Check if the invitation exists and if the reward is already claimed
        $checkInvitationQuery = "SELECT is_claimed_reward FROM invitations WHERE inviter_id = ? AND invited_id = ?";
        $checkInvitationStmt = $conn->prepare($checkInvitationQuery);
        $checkInvitationStmt->bind_param('ss', $inviter_id, $invited_id);
        $checkInvitationStmt->execute();

        $result = $checkInvitationStmt->get_result();
        if ($result->num_rows > 0) {
            $row = $result->fetch_assoc();
            if ($row['is_claimed_reward']) {
                
                $response = [
                    'status' => 'error',
                    'message' => 'Reward has already been claimed.'
                ];
            } else {
                addNewTransaction($inviter_id, $amount, $description);
                // Update the invitation to mark the reward as claimed
                $updateQuery = "UPDATE invitations SET is_claimed_reward = TRUE WHERE inviter_id = ? AND invited_id = ?";
                $updateStmt = $conn->prepare($updateQuery);
                $updateStmt->bind_param('ss', $inviter_id, $invited_id);
                $updateStmt->execute();

                if ($updateStmt->affected_rows > 0) {
                    $response = [
                        'status' => 'success',
                        'message' => 'Reward claimed successfully.'
                    ];
                } else {
                    $response = [
                        'status' => 'error',
                        'message' => 'Failed to claim reward.'
                    ];
                }
                $updateStmt->close();
            }
        } else {
            $response = [
                'status' => 'error',
                'message' => 'No invitation found for the given users.'
            ];
        }
        $checkInvitationStmt->close();
    } catch (Exception $e) {
        $response = [
            'status' => 'error',
            'message' => 'Error: ' . $e->getMessage()
        ];
    }
} else {
    $response = [
        'status' => 'error',
        'message' => 'Missing required parameters.'
    ];
}

echo json_encode($response);

function addNewTransaction($userId, $amount, $description) {
    global $conn;
    $transId = uniqid('trans_', true);
    $transDate = date('Y-m-d H:i:s');
    $type = 'credit';

    $stmt = $conn->prepare("INSERT INTO transactions (trans_id, trans_date, amount, type, description, userid) VALUES (?, ?, ?, ?, ?, ?)");
    $stmt->bind_param("ssdsss", $transId, $transDate, $amount, $type, $description, $userId);

    return $stmt->execute();
}
$conn->close();
?>
