<?php
require_once 'db.php';

function getUserOverallBalance($userId) {
    global $conn;
    $stmt = $conn->prepare("SELECT SUM(amount) as balance FROM transactions WHERE userid = ? AND type = 'credit'");
    $stmt->bind_param("s", $userId);

    if ($stmt->execute()) {
        $result = $stmt->get_result();
        if ($row = $result->fetch_assoc()) {
            return $row['balance'] ?? 0;
        }
    }
    return 0;
}

function getNextLeagueReward($balance) {
    global $conn;
    $stmt = $conn->prepare("SELECT name, threshold, reward FROM league_reward WHERE threshold <= ? ORDER BY threshold DESC LIMIT 1");
    $stmt->bind_param("d", $balance);

    if ($stmt->execute()) {
        $result = $stmt->get_result();
        if ($row = $result->fetch_assoc()) {
            return $row;
        }
    }
    return null;
}

function hasClaimedLeagueReward($userId, $name, $threshold) {
    global $conn;
    $stmt = $conn->prepare("SELECT 1 FROM is_claimed_leagues WHERE userid = ? AND name = ? AND threshold = ?");
    $stmt->bind_param("ssd", $userId, $name, $threshold);

    if ($stmt->execute()) {
        return $stmt->get_result()->num_rows > 0;
    }
    return false;
}

function claimLeagueReward($userId, $name, $threshold) {
    global $conn;
    $stmt = $conn->prepare("INSERT INTO is_claimed_leagues (userid, name, threshold) VALUES (?, ?, ?)");
    $stmt->bind_param("ssd", $userId, $name, $threshold);

    return $stmt->execute();
}

function addNewTransaction($userId, $amount, $description) {
    global $conn;
    $transId = uniqid('trans_', true);
    $transDate = date('Y-m-d H:i:s');
    $type = 'credit';

    $stmt = $conn->prepare("INSERT INTO transactions (trans_id, trans_date, amount, type, description, userid) VALUES (?, ?, ?, ?, ?, ?)");
    $stmt->bind_param("ssdsss", $transId, $transDate, $amount, $type, $description, $userId);

    return $stmt->execute();
}

$data = json_decode(file_get_contents('php://input'), true);

if (isset($data['user_id'])) {
    $userId = $data['user_id'];
    $balance = getUserOverallBalance($userId);

    if ($balance !== false) {
        $leagueInfo = getNextLeagueReward($balance);

        if ($leagueInfo && !hasClaimedLeagueReward($userId, $leagueInfo['name'], $leagueInfo['threshold'])) {
            if (claimLeagueReward($userId, $leagueInfo['name'], $leagueInfo['threshold'])) {
                if (addNewTransaction($userId, $leagueInfo['reward'], "League reward claimed for threshold {$leagueInfo['threshold']}")) {
                    echo json_encode(['message' => 'Reward claimed successfully', 'reward' => $leagueInfo['reward']]);
                } else {
                    http_response_code(500);
                    echo json_encode(['error' => 'Unable to add transaction']);
                }
            } else {
                http_response_code(500);
                echo json_encode(['error' => 'Unable to claim reward']);
            }
        } else {
            http_response_code(400);
            echo json_encode(['error' => 'No eligible reward to claim or already claimed']);
        }
    } else {
        http_response_code(500);
        echo json_encode(['error' => 'Unable to fetch user balance']);
    }
} else {
    http_response_code(400);
    echo json_encode(['error' => 'User ID is required']);
}

$conn->close();
?>
