<?php
require_once 'db.php';

function refillBoosts($userId) {
    global $conn;

    $stmt = $conn->prepare("
        SELECT 
            boostme_next_refill_time, 
            supergo_next_refill_time,
            daily_reward_next_refill_time,
            like_retweet_next_refill_time
        FROM 
            user_boosts 
        WHERE 
            user_id = ?
    ");
    $stmt->bind_param("s", $userId);

    if ($stmt->execute()) {
        $result = $stmt->get_result();
        if ($row = $result->fetch_assoc()) {
            $currentDateTime = new DateTime();
            $messiRefillTime = new DateTime($row['boostme_next_refill_time']);
            $ronaldoRefillTime = new DateTime($row['supergo_next_refill_time']);
            $daily_reward_next_refill_time = new DateTime($row['daily_reward_next_refill_time']);
            $like_retweet_next_refill_time = new DateTime($row['like_retweet_next_refill_time']);

            $shouldRefillMessi = $currentDateTime >= $messiRefillTime;
            $shouldRefillRonaldo = $currentDateTime >= $ronaldoRefillTime;
            $shouldRefillDailyReward = $currentDateTime >= $daily_reward_next_refill_time;
            $shouldRefillLikeRetweet = $currentDateTime >= $like_retweet_next_refill_time;

            if ($shouldRefillMessi || $shouldRefillRonaldo || $shouldRefillDailyReward || $shouldRefillLikeRetweet) {
                $updateQuery = "UPDATE user_boosts SET ";
                

                if ($shouldRefillMessi) {
                    $updateQuery .= "boostme_left = 3, boostme_next_refill_time = DATE_ADD(NOW(), INTERVAL 1 DAY)";
                    
                }

                if ($shouldRefillRonaldo) {
                    if ($shouldRefillMessi) {
                        $updateQuery .= ", ";
                    }
                    $updateQuery .= "supergo_left = 3, supergo_next_refill_time = DATE_ADD(NOW(), INTERVAL 1 DAY)";
                   
                }
                if ($shouldRefillDailyReward) {
                    if ($shouldRefillMessi || $shouldRefillRonaldo) {
                        $updateQuery .= ", ";
                    }
                    $updateQuery .= "daily_reward_claimed = 0, daily_reward_next_refill_time = DATE_ADD(NOW(), INTERVAL 1 DAY)";
                   
                }
                if ($shouldRefillLikeRetweet) {
                    if ($shouldRefillMessi || $shouldRefillRonaldo || $shouldRefillDailyReward) {
                        $updateQuery .= ", ";
                    }
                    $updateQuery .= "like_retweet_claimed = 0, like_retweet_next_refill_time = DATE_ADD(NOW(), INTERVAL 1 DAY)";
                   
                }

                $updateQuery .= " WHERE user_id = ?";
               

                $stmtUpdate = $conn->prepare($updateQuery);
                $stmtUpdate->bind_param("s",$userId);
                $stmtUpdate->execute();
                $stmtUpdate->close();
            }
        }
    } else {
        echo "Error executing query: " . $stmt->error;
    }

    $stmt->close();
}

function processDailyBoosts() {
    global $conn;
    $stmt = $conn->prepare("SELECT user_id FROM user_boosts");

    if ($stmt->execute()) {
        $result = $stmt->get_result();
        while ($row = $result->fetch_assoc()) {
            refillBoosts($row['user_id']);
        }
    } else {
        echo "Error executing query: " . $stmt->error;
    }

    $stmt->close();
}

// Call this function to process daily boosts for all users.
processDailyBoosts();
?>
