<?php
require_once 'db.php';

function createUser($userId, $farmWalletId, $chatId = null, $imagePath = null, $inviteLink = null, $walletAddress = null) {
    global $conn;
    
    // Check if the username already exists
    $stmt = $conn->prepare("SELECT COUNT(*) FROM users WHERE user_id = ?");
    $stmt->bind_param("s", $user_id);
    $stmt->execute();
    $stmt->bind_result($user_count);
    $stmt->fetch();
    $stmt->close();

    if ($user_count > 0) {
        return json_encode(['error' => 'Username chosen']);
        
    }
    $stmt = $conn->prepare("
        INSERT INTO users (user_id, ref_code, wallet_address, farm_wallet_id)
        VALUES (?, ?, ?, ?)
    ");
    $stmt->bind_param("ssss", $userId, $inviteLink, $walletAddress, $farmWalletId);

    return $stmt->execute();
}



function initializeUserBoosts($userId) {
    global $conn;
    $stmt = $conn->prepare("
        INSERT INTO user_boosts (
            user_id,
            boostme_left,
            boostme_next_refill_time,
            supergo_left,
            supergo_next_refill_time,
            supertap_level,
            energy_level,
            daily_reward_claimed,
            daily_reward_next_refill_time,
            like_retweet_claimed,
            like_retweet_next_refill_time
        ) VALUES (
            ?, 
            3, 
            DATE_ADD(NOW(), INTERVAL 1 DAY), 
            3, 
            DATE_ADD(NOW(), INTERVAL 1 DAY), 
            0, 
            0,
            0,
            DATE_ADD(NOW(), INTERVAL 1 DAY),
            0,
            DATE_ADD(NOW(), INTERVAL 1 DAY)
        )
    ");
  
    $stmt->bind_param("s", $userId);

    return $stmt->execute();
}
function initializeFarm($user_id) {
    global $conn;
    // Initialize user_farm table
    $farm_amount_per_hour = 10;
    $next_farm_claim_time = date('Y-m-d H:i:s', strtotime('+1 hour'));
    $farming_status = 'inactive';
    $sqlInsertUserFarm = "INSERT INTO user_farm (farm_amount_per_hour, next_farm_claim_time, farming_status, user_id) VALUES ($farm_amount_per_hour, '$next_farm_claim_time', '$farming_status', '$user_id')";
    if ($conn->query($sqlInsertUserFarm) === TRUE ) {
        //echo json_encode(['success' => 'User farm initialized successfully']);
    } else {
        echo json_encode(['error' => 'Error initializing user data: ' . $conn->error]);
    }
}
function generateRandom4DigitCode() {
    return rand(1000, 9999);
}

$data = json_decode(file_get_contents('php://input'), true);

if (isset($data['user_id'])) {
    $userId = $data['user_id'];
    $chatId = isset($data['chat_id']) ? $data['chat_id'] : null;
    $imagePath = isset($data['image_path']) ? $data['image_path'] : null;
    $inviter= generateRandom4DigitCode();
    $farmWalletId = generateRandom4DigitCode();
    $inviteLink = $inviter;
    $walletAddress = isset($data['wallet_address']) ? $data['wallet_address'] : null;

    $conn->begin_transaction();
    try {
        if (createUser($userId, $farmWalletId, $chatId, $imagePath, $inviteLink, $walletAddress) && initializeUserBoosts($userId)) {
            $conn->commit();
            http_response_code(200);
            initializeFarm($userId);
            echo json_encode(['message' => 'User created and boosts initialized successfully']);
        } else {
            $conn->rollback();
            http_response_code(500);
            echo json_encode(['error' => 'Unable to create user or initialize boosts']);
        }
    } catch (Exception $e) {
        $conn->rollback();
        http_response_code(500);
        echo json_encode(['error' => 'Transaction failed: ' . $e->getMessage()]);
    }
} else {
    http_response_code(400);
    echo json_encode(['error' => 'User ID is required']);
}

$conn->close();
?>
