<?php
require_once 'db.php';

$data = json_decode(file_get_contents('php://input'), true);

if (isset($data['ref_code']) && isset($data['invited_id'])) {
    $ref_code = intval($data['ref_code']);
    $invited_id = htmlspecialchars($data['invited_id']);

    try {
        // Check if the invited user exists
        $checkUserQuery = "SELECT user_id FROM users WHERE user_id = ?";
        $checkUserStmt = $conn->prepare($checkUserQuery);
        $checkUserStmt->bind_param('s', $invited_id);
        $checkUserStmt->execute();

        $checkUserResult = $checkUserStmt->get_result();
        if ($checkUserResult->num_rows == 0) {
            $response = [
                'status' => 'error',
                'message' => 'Invited user does not exist.'
            ];
            echo json_encode($response);
            $checkUserStmt->close();
            $conn->close();
            exit();
        }
        $checkUserStmt->close();

        // Get inviter_id using ref_code
        $query = "SELECT user_id FROM users WHERE ref_code = ?";
        $stmt = $conn->prepare($query);
        $stmt->bind_param('i', $ref_code);
        $stmt->execute();

        $result = $stmt->get_result();
        $row = $result->fetch_assoc();

        if ($row) {
            $inviter_id = $row['user_id'];

            // Insert into invitations table
            $insertQuery = "INSERT INTO invitations (inviter_id, invited_id, date) VALUES (?, ?, UTC_TIMESTAMP())";
            $insertStmt = $conn->prepare($insertQuery);
            $insertStmt->bind_param('ss', $inviter_id, $invited_id);
            $insertStmt->execute();

            if ($insertStmt->affected_rows > 0) {
                $response = [
                    'status' => 'success',
                    'message' => 'Invitation added successfully.'
                ];
            } else {
                $response = [
                    'status' => 'error',
                    'message' => 'Failed to add invitation.'
                ];
            }
            $insertStmt->close();
        } else {
            $response = [
                'status' => 'error',
                'message' => 'Invalid referral code.'
            ];
        }
        $stmt->close();
    } catch (Exception $e) {
        $response = [
            'status' => 'error',
            'message' => 'Error: ' . $e->getMessage()
        ];
    }
} else {
    $response = [
        'status' => 'error',
        'message' => 'Missing required parameters.'
    ];
}

echo json_encode($response);

$conn->close();
?>
