<?php
require_once 'db.php';

function getUserInvited($userId) {
    global $conn;

    // Prepare the SQL statement to fetch invited users along with their balance and league information
    $stmt = $conn->prepare("
       SELECT 
            invitations.invited_id, 
            invitations.date,
            IFNULL(transactions.total_credit, 0) as balance,
            CASE
                WHEN IFNULL(transactions.total_credit, 0) BETWEEN 0 AND 99999 THEN 'Premeira'
                WHEN IFNULL(transactions.total_credit, 0) BETWEEN 100000 AND 999999 THEN 'Eredivisie'
                WHEN IFNULL(transactions.total_credit, 0) BETWEEN 1000000 AND 9999999 THEN 'Ligue Un'
                WHEN IFNULL(transactions.total_credit, 0) BETWEEN 10000000 AND 99999999 THEN 'Bundesliga'
                WHEN IFNULL(transactions.total_credit, 0) BETWEEN 100000000 AND 499999999 THEN 'Serie A'
                WHEN IFNULL(transactions.total_credit, 0) BETWEEN 500000000 AND 999999999 THEN 'La Liga'
                WHEN IFNULL(transactions.total_credit, 0) >= 1000000000 THEN 'Premier League'
                ELSE 'Unknown'
            END as league
        FROM 
            invitations
        LEFT JOIN 
            (SELECT userid, SUM(amount) as total_credit FROM transactions WHERE type = 'credit' GROUP BY userid) as transactions
            ON invitations.invited_id = transactions.userid
        WHERE 
            invitations.inviter_id =?;
    ");
    $stmt->bind_param("s", $userId);

    if ($stmt->execute()) {
        $result = $stmt->get_result();
        $invitedUsers = [];
        while ($row = $result->fetch_assoc()) {
            $invitedUsers[] = $row;
        }
        return $invitedUsers;
    } else {
        echo "Error executing query: " . $stmt->error;
        return false;
    }

    $stmt->close();
}

$data = json_decode(file_get_contents('php://input'), true);
if (isset($data['user_id'])) {
    $userId = $data['user_id'];
    $invitedUsers = getUserInvited($userId);
    if ($invitedUsers !== false) {
        echo json_encode(['invited_users' => $invitedUsers]);
    } else {
        http_response_code(500);
        echo json_encode(['error' => 'Unable to fetch invited users']);
    }
} else {
    http_response_code(400);
    echo json_encode(['error' => 'User ID is required']);
}

$conn->close();
?>
