<?php
require_once 'db.php';

$data = json_decode(file_get_contents('php://input'), true);

if (isset($data['user_id'])) {
    $userid = htmlspecialchars($data['user_id']);

    try {
        // Query to get the tasks done by the user
        $query = "
            SELECT dt.task_id, t.name, t.description, t.reward, t.start_date, t.end_date, t.redirect_link
            FROM done_tasks dt
            JOIN tasks t ON dt.task_id = t.task_id
            WHERE dt.userid = ?";
        $stmt = $conn->prepare($query);
        $stmt->bind_param('s', $userid);
        $stmt->execute();

        $result = $stmt->get_result();
        $tasks = [];

        while ($row = $result->fetch_assoc()) {
            $tasks[] = $row;
        }

        if (count($tasks) > 0) {
            $response = [
                'status' => 'success',
                'tasks' => $tasks
            ];
        } else {
            $response = [
                'status' => 'error',
                'message' => 'No tasks done for the given user.'
            ];
        }

        $stmt->close();
    } catch (Exception $e) {
        $response = [
            'status' => 'error',
            'message' => 'Error: ' . $e->getMessage()
        ];
    }
} else {
    $response = [
        'status' => 'error',
        'message' => 'Missing required parameters.'
    ];
}

echo json_encode($response);

$conn->close();
?>
