<?php
require_once 'db.php';

function getTaskReward($taskId) {
    global $conn;

    $stmt = $conn->prepare("SELECT reward FROM tasks WHERE task_id = ?");
    $stmt->bind_param("s", $taskId);

    if ($stmt->execute()) {
        $result = $stmt->get_result();
        if ($row = $result->fetch_assoc()) {
            return $row['reward'];
        } else {
            return null;
        }
    } else {
        echo "Error executing query: " . $stmt->error;
        return false;
    }

    $stmt->close();
}

function saveDoneTask($userId, $taskId) {
    global $conn;

    // Check if the task is already completed by the user
    $checkStmt = $conn->prepare("SELECT COUNT(*) AS count FROM done_tasks WHERE userid = ? AND task_id = ?");
    $checkStmt->bind_param("ss", $userId, $taskId);

    if ($checkStmt->execute()) {
        $result = $checkStmt->get_result();
        $row = $result->fetch_assoc();
        
        if ($row['count'] > 0) {
            // Task already exists
            return false;//['success' => false, 'message' => 'Task already completed.'];
        }
    } else {
        echo "Error executing check query: " . $checkStmt->error;
        return false;//['success' => false, 'message' => 'Error checking task completion.'];
    }

    $checkStmt->close();

    // Insert the new completed task
    $insertStmt = $conn->prepare("INSERT INTO done_tasks (userid, task_id) VALUES (?, ?)");
    $insertStmt->bind_param("ss", $userId, $taskId);

    if ($insertStmt->execute()) {
        $insertStmt->close();
        return ['success' => true, 'message' => 'Task marked as completed.'];
    } else {
        echo "Error executing insert query: " . $insertStmt->error;
        $insertStmt->close();
        return false;//['success' => false, 'message' => 'Error marking task as completed.'];
    }
}


function addNewTransaction($userId, $amount, $description) {
    global $conn;

    $transId = uniqid('trans_', true);
    $transDate = date('Y-m-d H:i:s');
    $type = 'credit';

    $stmt = $conn->prepare("INSERT INTO transactions (trans_id, trans_date, amount, type, description, userid) VALUES (?, ?, ?, ?, ?, ?)");
    $stmt->bind_param("ssdsss", $transId, $transDate, $amount, $type, $description, $userId);

    if ($stmt->execute()) {
        return true;
    } else {
        echo "Error executing query: " . $stmt->error;
        return false;
    }

    $stmt->close();
}

$data = json_decode(file_get_contents('php://input'), true);

if (isset($data['user_id']) && isset($data['task_id'])) {
    $userId = $data['user_id'];
    $taskId = $data['task_id'];

    if (saveDoneTask($userId, $taskId)) {
        $reward = getTaskReward($taskId);
        if ($reward !== false && $reward !== null) {
            if (addNewTransaction($userId, $reward, "Task reward for task $taskId")) {
                echo json_encode(['message' => 'Task saved and reward claimed successfully', 'reward' => $reward]);
            } else {
                http_response_code(500);
                echo json_encode(['error' => 'Unable to add transaction']);
            }
        } else {
            http_response_code(400);
            echo json_encode(['error' => 'Task not found']);
        }
    } else {
        http_response_code(500);
        echo json_encode(['error' => 'Task is already rewarded']);
    }
} else {
    http_response_code(400);
    echo json_encode(['error' => 'User ID and Task ID are required']);
}

$conn->close();
?>
