<?php
require_once 'db.php';

function createUser($userId, $chatId = null, $imagePath = null, $inviteLink = null, $walletAddress = null) {
    global $conn;
    
    // Check if the username already exists
    $stmt = $conn->prepare("SELECT COUNT(*) FROM users WHERE user_id = ?");
    $stmt->bind_param("s", $user_id);
    $stmt->execute();
    $stmt->bind_result($user_count);
    $stmt->fetch();
    $stmt->close();

    if ($user_count > 0) {
        return json_encode(['error' => 'Username chosen']);
        exit;
    }
    $stmt = $conn->prepare("
        INSERT INTO users (user_id, ref_code, wallet_address)
        VALUES (?, ?, ?)
    ");
    $stmt->bind_param("sss", $userId, $inviteLink, $walletAddress);

    return $stmt->execute();
}



function initializeUserBoosts($userId) {
    global $conn;
    $stmt = $conn->prepare("
        INSERT INTO user_boosts (
            user_id,
            boostme_left,
            boostme_next_refill_time,
            supergo_left,
            supergo_next_refill_time,
            supertap_level,
            energy_level
        ) VALUES (
            ?, 
            3, 
            DATE_ADD(NOW(), INTERVAL 1 DAY), 
            3, 
            DATE_ADD(NOW(), INTERVAL 1 DAY), 
            1, 
            1000
        )
    ");
    $stmt->bind_param("s", $userId);

    return $stmt->execute();
}

function generateRandom4DigitCode() {
    return rand(1000, 9999);
}

$data = json_decode(file_get_contents('php://input'), true);

if (isset($data['user_id'])) {
    $userId = $data['user_id'];
    $chatId = isset($data['chat_id']) ? $data['chat_id'] : null;
    $imagePath = isset($data['image_path']) ? $data['image_path'] : null;
    $inviter= generateRandom4DigitCode();
    $inviteLink = $inviter;
    $walletAddress = isset($data['wallet_address']) ? $data['wallet_address'] : null;

    $conn->begin_transaction();
    try {
        if (createUser($userId, $chatId, $imagePath, $inviteLink, $walletAddress) && initializeUserBoosts($userId)) {
            $conn->commit();
            http_response_code(200);
            echo json_encode(['message' => 'User created and boosts initialized successfully']);
        } else {
            $conn->rollback();
            http_response_code(500);
            echo json_encode(['error' => 'Unable to create user or initialize boosts']);
        }
    } catch (Exception $e) {
        $conn->rollback();
        http_response_code(500);
        echo json_encode(['error' => 'Transaction failed: ' . $e->getMessage()]);
    }
} else {
    http_response_code(400);
    echo json_encode(['error' => 'User ID is required']);
}

$conn->close();
?>
