<?php
require_once 'db.php';

function getInviteCount($userId) {
    global $conn;

    $stmt = $conn->prepare("SELECT COUNT(*) as invite_count FROM invitations WHERE inviter_id = ?");
    $stmt->bind_param("s", $userId);

    if ($stmt->execute()) {
        $result = $stmt->get_result();
        if ($row = $result->fetch_assoc()) {
            return $row['invite_count'];
        } else {
            return 0;
        }
    } else {
        echo "Error executing query: " . $stmt->error;
        return false;
    }

    $stmt->close();
}

function getNextThresholdInfo($userId, $currentCount) {
    global $conn;

    // Prepare the statement to get the next threshold and reward
    $stmt = $conn->prepare("
        SELECT ir.threshold, ir.reward 
        FROM invite_rewards ir
        LEFT JOIN is_claimed_invite ici ON ir.threshold = ici.threshold AND ici.userid = ?
        WHERE ir.threshold > ? AND ici.userid IS NULL
        ORDER BY ir.threshold ASC 
        LIMIT 1
    ");
    $stmt->bind_param("si", $userId, $currentCount);

    if ($stmt->execute()) {
        $result = $stmt->get_result();
        if ($row = $result->fetch_assoc()) {
            return $row;
        } else {
            return null;
        }
    } else {
        echo "Error executing query: " . $stmt->error;
        return false;
    }

    $stmt->close();
}

$data = json_decode(file_get_contents('php://input'), true);
if (isset($data['user_id'])) {
    $userId = $data['user_id'];
    $inviteCount = getInviteCount($userId);

    if ($inviteCount !== false) {
        $nextThresholdInfo = getNextThresholdInfo($userId, $inviteCount);

        if ($nextThresholdInfo !== false) {
            echo json_encode([
                'invite_count' => $inviteCount,
                'next_threshold' => $nextThresholdInfo ? $nextThresholdInfo['threshold'] : null,
                'next_reward' => $nextThresholdInfo ? $nextThresholdInfo['reward'] : null
            ]);
        } else {
            http_response_code(500);
            echo json_encode(['error' => 'Unable to fetch next threshold info']);
        }
    } else {
        http_response_code(500);
        echo json_encode(['error' => 'Unable to fetch invite count']);
    }
} else {
    http_response_code(400);
    echo json_encode(['error' => 'User ID is required']);
}

$conn->close();
?>
