<?php
require_once 'db.php';

function getUserOverallBalance($userId) {
    global $conn;

    $stmt = $conn->prepare("SELECT SUM(amount) as balance FROM transactions WHERE userid = ? AND type = 'credit'");
    $stmt->bind_param("s", $userId);

    if ($stmt->execute()) {
        $result = $stmt->get_result();
        if ($row = $result->fetch_assoc()) {
            return $row['balance'] ?? 0;
        } else {
            return 0;
        }
    } else {
        echo "Error executing query: " . $stmt->error;
        return false;
    }

    $stmt->close();
}

function getCurrentLeague($balance) {
    if ($balance <= 99999) {
        return 'Premeira';
    } elseif ($balance <= 999999) {
        return 'Eredivisie';
    } elseif ($balance <= 9999999) {
        return 'Ligue Un';
    } elseif ($balance <= 99999999) {
        return 'Bundesliga';
    } elseif ($balance <= 499999999) {
        return 'Serie A';
    } elseif ($balance <= 999999999) {
        return 'La Liga';
    } else {
        return 'Premier League';
    }
}
function getLeagueInfo($leagueName) {
    global $conn;

    $stmt = $conn->prepare("SELECT * FROM league_reward WHERE name = ?");
    $stmt->bind_param("s", $leagueName);

    if ($stmt->execute()) {
        $result = $stmt->get_result();
        if ($row = $result->fetch_assoc()) {
            return $row;
        } else {
            return null;
        }
    } else {
        echo "Error executing query: " . $stmt->error;
        return false;
    }

    $stmt->close();
}

$data = json_decode(file_get_contents('php://input'), true);
if (isset($data['user_id'])) {
    $userId = $data['user_id'];
    //require 'get_user_current_league.php'; // To reuse the logic to get user's current league
    $leagueName = getCurrentLeague(getUserOverallBalance($userId));

    if ($leagueName !== false && $leagueName !== null) {
        $leagueInfo = getLeagueInfo($leagueName);

        if ($leagueInfo !== false && $leagueInfo !== null) {
            echo json_encode(['league_info' => $leagueInfo]);
        } else {
            http_response_code(500);
            echo json_encode(['error' => 'Unable to fetch league info']);
        }
    } else {
        http_response_code(500);
        echo json_encode(['error' => 'Unable to fetch current league']);
    }
} else {
    http_response_code(400);
    echo json_encode(['error' => 'User ID is required']);
}

$conn->close();
